==> cybop-0.23.0-Linux.tar.gz: cybop-0.23.0-Linux/src/constant/name/cybol/logic/access/get_index_access_logic_cybol_name.c <==
/*
 * Copyright (C) 1999-2022. Christian Heller.
 *
 * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
 *
 * CYBOI is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * CYBOI is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CYBOI. If not, see <http://www.gnu.org/licenses/>.
 *
 * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
 * CYBOP Developers <cybop-developers@nongnu.org>
 *
 * @version CYBOP 0.23.0 2022-09-04
 * @author Christian Heller <christian.heller@cybop.org>
 */

#ifndef GET_INDEX_ACCESS_LOGIC_CYBOL_NAME_CONSTANT_SOURCE
#define GET_INDEX_ACCESS_LOGIC_CYBOL_NAME_CONSTANT_SOURCE

#include <stddef.h>

#include "../../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"

/** The index get index access logic cybol name. */
static wchar_t* INDEX_GET_INDEX_ACCESS_LOGIC_CYBOL_NAME = L"index";
static int* INDEX_GET_INDEX_ACCESS_LOGIC_CYBOL_NAME_COUNT = NUMBER_5_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The part get index access logic cybol name. */
static wchar_t* PART_GET_INDEX_ACCESS_LOGIC_CYBOL_NAME = L"part";
static int* PART_GET_INDEX_ACCESS_LOGIC_CYBOL_NAME_COUNT = NUMBER_4_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The whole get index access logic cybol name. */
static wchar_t* WHOLE_GET_INDEX_ACCESS_LOGIC_CYBOL_NAME = L"whole";
static int* WHOLE_GET_INDEX_ACCESS_LOGIC_CYBOL_NAME_COUNT = NUMBER_5_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/* GET_INDEX_ACCESS_LOGIC_CYBOL_NAME_CONSTANT_SOURCE */
#endif

==> cybop-0.24.0-Linux.tar.gz: cybop-0.24.0-Linux/src/constant/name/cybol/logic/access/get_index_access_logic_cybol_name.c <==
/*
 * Copyright (C) 1999-2022. Christian Heller.
 *
 * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
 *
 * CYBOI is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * CYBOI is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CYBOI. If not, see <http://www.gnu.org/licenses/>.
 *
 * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
 * CYBOP Developers <cybop-developers@nongnu.org>
 *
 * @version CYBOP 0.24.0 2022-12-24
 * @author Christian Heller <christian.heller@cybop.org>
 */

#ifndef GET_INDEX_ACCESS_LOGIC_CYBOL_NAME_CONSTANT_SOURCE
#define GET_INDEX_ACCESS_LOGIC_CYBOL_NAME_CONSTANT_SOURCE

#include <stddef.h>

#include "../../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"

/** The index get index access logic cybol name. */
static wchar_t* INDEX_GET_INDEX_ACCESS_LOGIC_CYBOL_NAME = L"index";
static int* INDEX_GET_INDEX_ACCESS_LOGIC_CYBOL_NAME_COUNT = NUMBER_5_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The name get index access logic cybol name. */
static wchar_t* NAME_GET_INDEX_ACCESS_LOGIC_CYBOL_NAME = L"name";
static int* NAME_GET_INDEX_ACCESS_LOGIC_CYBOL_NAME_COUNT = NUMBER_4_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The whole get index access logic cybol name. */
static wchar_t* WHOLE_GET_INDEX_ACCESS_LOGIC_CYBOL_NAME = L"whole";
static int* WHOLE_GET_INDEX_ACCESS_LOGIC_CYBOL_NAME_COUNT = NUMBER_5_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/* GET_INDEX_ACCESS_LOGIC_CYBOL_NAME_CONSTANT_SOURCE */
#endif
